@@ -16,7 +16,7 @@ class Response:
         return {}
 
     def response_body_bytes(self):
-        return ""
+        return "".encode("utf-8")
 
 
 class ErrorResponse(Response):
@@ -77,8 +77,8 @@ class Action:
 
 
 class JsonGet(Action):
-    def __init__(self, path, callable):
-        self.path = path
+    def __init__(self, endpoint, callable):
+        self.path = endpoint
         self.callable = callable
 
     def can_handle(self, method, path, params, payload):
@@ -90,8 +90,8 @@ class JsonGet(Action):
 
 
 class JsonPost(Action):
-    def __init__(self, path, callable):
-        self.path = path
+    def __init__(self, endpoint, callable):
+        self.path = endpoint
         self.callable = callable
 
     def can_handle(self, method, path, params, payload):
